Struct DescriptorPublicKey

pub struct DescriptorPublicKey(/* private fields */);
A descriptor public key.

Implementations

Source

impl DescriptorPublicKey

pub fn from_string(public_key: String) -> Result<Self, DescriptorKeyError>

Attempt to parse a string as a descriptor public key.

pub fn derive( &self, path: &DerivationPath, ) -> Result<Arc<Self>, DescriptorKeyError>

Derive the descriptor public key at the given derivation path.

pub fn extend( &self, path: &DerivationPath, ) -> Result<Arc<Self>, DescriptorKeyError>

Extend the descriptor public key by the given derivation path.

pub fn add_wildcard(&self) -> Result<Arc<Self>, DescriptorKeyError>

Add an unhardened wildcard derivation step (*) to this extended public key.

Public keys only support unhardened wildcards since xpubs cannot derive hardened children. If the key already has an unhardened wildcard, it is returned unchanged. Returns an error if the key is not a single xpub, or if the key already has a hardened wildcard.

pub fn is_multipath(&self) -> bool

Whether or not this key has multiple derivation paths.

pub fn master_fingerprint(&self) -> String

The fingerprint of the master key associated with this key, 0x00000000 if none.